
======================
Leonardo import Export
======================

Small glue around Django Import Export and Leonardo CMS

Installation
------------

.. code-block:: bash

    pip install leonardo-import-export

Read More
=========

* https://github.com/django-import-export/django-import-export
* https://github.com/django-leonardo
* https://github.com/leonardo-modules/leonardo-import-export
